from codecs import open  # To use a consistent encoding

class Settings():

    def __init__(self):
        self.name = 'qtarmsim'
        self.version = self._get_version()
        self.description = 'Qt graphical frontend to ARMSim'
        self.url = 'http://lorca.act.uji.es/projects/qtarmsim/'
        self.author = 'Sergio Barrachina Mir'
        self.email = 'barrachi@uji.es'
        self.license = 'GPLV3+'
        self.package_data = {
                             'qtarmsim': ['armsim/*', 'test/add.s', 'html/*.html', 'html/img/*'],
                             }
        # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
        self.classifiers = [
            # How mature is this project? Common values are
            #   3 - Alpha
            #   4 - Beta
            #   5 - Production/Stable
            'Development Status :: 5 - Production/Stable',
    
            # Who the project is intended for
            'Intended Audience :: Education',
            'Topic :: Software Development :: Assemblers',
            'Topic :: Software Development :: Debuggers',
            'Topic :: Software Development :: Disassemblers',
    
            # License long description
            'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
    
            # Python versions supported
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.2',
            'Programming Language :: Python :: 3.3',
            'Programming Language :: Python :: 3.4',
            ]
        self.keywords = ['ARM', 'simulator', 'assembler', 'disassembler', 'debugger']


    def _get_version(self):
        """Gets version from 'qtarmsim/version.py'."""
        version_dict = {}
        with open('qtarmsim/version.py') as fp:
            exec(fp.read(), version_dict)
        return version_dict['__version__']



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/preferences.ui'
#
# Created: Tue Sep  2 17:00:02 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_PreferencesDialog(object):
    def setupUi(self, PreferencesDialog):
        PreferencesDialog.setObjectName(_fromUtf8("PreferencesDialog"))
        PreferencesDialog.resize(660, 388)
        self.verticalLayout = QtGui.QVBoxLayout(PreferencesDialog)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.tabWidget = QtGui.QTabWidget(PreferencesDialog)
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.tabARMSim = QtGui.QWidget()
        self.tabARMSim.setObjectName(_fromUtf8("tabARMSim"))
        self.verticalLayout_4 = QtGui.QVBoxLayout(self.tabARMSim)
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.groupBox = QtGui.QGroupBox(self.tabARMSim)
        self.groupBox.setTitle(_fromUtf8("ARMSim"))
        self.groupBox.setFlat(False)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.formLayout = QtGui.QFormLayout()
        self.formLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName(_fromUtf8("formLayout"))
        self.labelARMSimCommand = QtGui.QLabel(self.groupBox)
        self.labelARMSimCommand.setObjectName(_fromUtf8("labelARMSimCommand"))
        self.formLayout.setWidget(4, QtGui.QFormLayout.LabelRole, self.labelARMSimCommand)
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.lineEditARMSimDirectory = QtGui.QLineEdit(self.groupBox)
        self.lineEditARMSimDirectory.setText(_fromUtf8(""))
        self.lineEditARMSimDirectory.setObjectName(_fromUtf8("lineEditARMSimDirectory"))
        self.horizontalLayout.addWidget(self.lineEditARMSimDirectory)
        self.toolButtonARMSimDirectory = QtGui.QToolButton(self.groupBox)
        self.toolButtonARMSimDirectory.setObjectName(_fromUtf8("toolButtonARMSimDirectory"))
        self.horizontalLayout.addWidget(self.toolButtonARMSimDirectory)
        self.formLayout.setLayout(4, QtGui.QFormLayout.FieldRole, self.horizontalLayout)
        self.label = QtGui.QLabel(self.groupBox)
        self.label.setObjectName(_fromUtf8("label"))
        self.formLayout.setWidget(3, QtGui.QFormLayout.LabelRole, self.label)
        self.lineEditARMSimCommand = QtGui.QLineEdit(self.groupBox)
        self.lineEditARMSimCommand.setObjectName(_fromUtf8("lineEditARMSimCommand"))
        self.formLayout.setWidget(3, QtGui.QFormLayout.FieldRole, self.lineEditARMSimCommand)
        self.labelARMSimServer = QtGui.QLabel(self.groupBox)
        self.labelARMSimServer.setObjectName(_fromUtf8("labelARMSimServer"))
        self.formLayout.setWidget(1, QtGui.QFormLayout.LabelRole, self.labelARMSimServer)
        self.lineEditARMSimServer = QtGui.QLineEdit(self.groupBox)
        self.lineEditARMSimServer.setText(_fromUtf8(""))
        self.lineEditARMSimServer.setObjectName(_fromUtf8("lineEditARMSimServer"))
        self.formLayout.setWidget(1, QtGui.QFormLayout.FieldRole, self.lineEditARMSimServer)
        self.labelARMSimPort = QtGui.QLabel(self.groupBox)
        self.labelARMSimPort.setObjectName(_fromUtf8("labelARMSimPort"))
        self.formLayout.setWidget(2, QtGui.QFormLayout.LabelRole, self.labelARMSimPort)
        self.spinBoxARMSimPort = QtGui.QSpinBox(self.groupBox)
        self.spinBoxARMSimPort.setMinimum(8000)
        self.spinBoxARMSimPort.setMaximum(9999)
        self.spinBoxARMSimPort.setProperty("value", 8010)
        self.spinBoxARMSimPort.setObjectName(_fromUtf8("spinBoxARMSimPort"))
        self.formLayout.setWidget(2, QtGui.QFormLayout.FieldRole, self.spinBoxARMSimPort)
        self.verticalLayout_2.addLayout(self.formLayout)
        self.verticalLayout_4.addWidget(self.groupBox)
        self.groupBox_2 = QtGui.QGroupBox(self.tabARMSim)
        self.groupBox_2.setTitle(_fromUtf8("GCC ARM"))
        self.groupBox_2.setFlat(False)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.verticalLayout_3 = QtGui.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.formLayout_2 = QtGui.QFormLayout()
        self.formLayout_2.setObjectName(_fromUtf8("formLayout_2"))
        self.lineEditARMGccOptions = QtGui.QLineEdit(self.groupBox_2)
        self.lineEditARMGccOptions.setText(_fromUtf8(""))
        self.lineEditARMGccOptions.setObjectName(_fromUtf8("lineEditARMGccOptions"))
        self.formLayout_2.setWidget(1, QtGui.QFormLayout.FieldRole, self.lineEditARMGccOptions)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.lineEditARMGccCommand = QtGui.QLineEdit(self.groupBox_2)
        self.lineEditARMGccCommand.setText(_fromUtf8(""))
        self.lineEditARMGccCommand.setObjectName(_fromUtf8("lineEditARMGccCommand"))
        self.horizontalLayout_2.addWidget(self.lineEditARMGccCommand)
        self.toolButtonARMGccCommand = QtGui.QToolButton(self.groupBox_2)
        self.toolButtonARMGccCommand.setObjectName(_fromUtf8("toolButtonARMGccCommand"))
        self.horizontalLayout_2.addWidget(self.toolButtonARMGccCommand)
        self.formLayout_2.setLayout(0, QtGui.QFormLayout.FieldRole, self.horizontalLayout_2)
        self.labelARMGccOptions = QtGui.QLabel(self.groupBox_2)
        self.labelARMGccOptions.setObjectName(_fromUtf8("labelARMGccOptions"))
        self.formLayout_2.setWidget(1, QtGui.QFormLayout.LabelRole, self.labelARMGccOptions)
        self.labelARMGccCommand = QtGui.QLabel(self.groupBox_2)
        self.labelARMGccCommand.setObjectName(_fromUtf8("labelARMGccCommand"))
        self.formLayout_2.setWidget(0, QtGui.QFormLayout.LabelRole, self.labelARMGccCommand)
        self.verticalLayout_3.addLayout(self.formLayout_2)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        spacerItem = QtGui.QSpacerItem(20, 43, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem)
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.pushButtonARMSimRestoreDefaults = QtGui.QPushButton(self.tabARMSim)
        self.pushButtonARMSimRestoreDefaults.setObjectName(_fromUtf8("pushButtonARMSimRestoreDefaults"))
        self.horizontalLayout_3.addWidget(self.pushButtonARMSimRestoreDefaults)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.tabWidget.addTab(self.tabARMSim, _fromUtf8(""))
        self.tab_2 = QtGui.QWidget()
        self.tab_2.setObjectName(_fromUtf8("tab_2"))
        self.tabWidget.addTab(self.tab_2, _fromUtf8(""))
        self.verticalLayout.addWidget(self.tabWidget)
        self.buttonBox = QtGui.QDialogButtonBox(PreferencesDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(PreferencesDialog)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), PreferencesDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), PreferencesDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(PreferencesDialog)

    def retranslateUi(self, PreferencesDialog):
        PreferencesDialog.setWindowTitle(_translate("PreferencesDialog", "Qt ARMSim Preferences", None))
        self.labelARMSimCommand.setText(_translate("PreferencesDialog", "ARMSim directory", None))
        self.toolButtonARMSimDirectory.setText(_translate("PreferencesDialog", "...", None))
        self.label.setText(_translate("PreferencesDialog", "Command line", None))
        self.labelARMSimServer.setText(_translate("PreferencesDialog", "Server", None))
        self.labelARMSimPort.setText(_translate("PreferencesDialog", "Port", None))
        self.toolButtonARMGccCommand.setText(_translate("PreferencesDialog", "...", None))
        self.labelARMGccOptions.setText(_translate("PreferencesDialog", "Options", None))
        self.labelARMGccCommand.setText(_translate("PreferencesDialog", "Command line", None))
        self.pushButtonARMSimRestoreDefaults.setText(_translate("PreferencesDialog", "Restore Defaults", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabARMSim), _translate("PreferencesDialog", "ARMSim", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/multi.ui'
#
# Created: Tue Sep  2 17:00:03 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Multipasos(object):
    def setupUi(self, Multipasos):
        Multipasos.setObjectName(_fromUtf8("Multipasos"))
        Multipasos.resize(400, 101)
        self.pasoslabel = QtGui.QLabel(Multipasos)
        self.pasoslabel.setGeometry(QtCore.QRect(20, 30, 87, 16))
        self.pasoslabel.setObjectName(_fromUtf8("pasoslabel"))
        self.pasos = QtGui.QLineEdit(Multipasos)
        self.pasos.setGeometry(QtCore.QRect(20, 50, 113, 20))
        self.pasos.setObjectName(_fromUtf8("pasos"))
        self.aceptarButton = QtGui.QPushButton(Multipasos)
        self.aceptarButton.setGeometry(QtCore.QRect(280, 20, 75, 23))
        self.aceptarButton.setObjectName(_fromUtf8("aceptarButton"))
        self.cancelarButton = QtGui.QPushButton(Multipasos)
        self.cancelarButton.setGeometry(QtCore.QRect(280, 60, 75, 23))
        self.cancelarButton.setObjectName(_fromUtf8("cancelarButton"))

        self.retranslateUi(Multipasos)
        QtCore.QMetaObject.connectSlotsByName(Multipasos)

    def retranslateUi(self, Multipasos):
        Multipasos.setWindowTitle(_translate("Multipasos", "Múltiples pasos", None))
        self.pasoslabel.setText(_translate("Multipasos", "Número de pasos:", None))
        self.aceptarButton.setText(_translate("Multipasos", "Aceptar", None))
        self.cancelarButton.setText(_translate("Multipasos", "Cancelar", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/mainwindow.ui'
#
# Created: Tue Sep  2 17:00:02 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(880, 716)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setWindowTitle(_fromUtf8("Qt ARMSim"))
        MainWindow.setTabShape(QtGui.QTabWidget.Rounded)
        MainWindow.setDockNestingEnabled(True)
        MainWindow.setDockOptions(QtGui.QMainWindow.AllowNestedDocks|QtGui.QMainWindow.AllowTabbedDocks|QtGui.QMainWindow.AnimatedDocks)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.tabWidgetCode = QtGui.QTabWidget(self.centralwidget)
        self.tabWidgetCode.setMinimumSize(QtCore.QSize(400, 400))
        self.tabWidgetCode.setTabPosition(QtGui.QTabWidget.South)
        self.tabWidgetCode.setObjectName(_fromUtf8("tabWidgetCode"))
        self.tabSource = QtGui.QWidget()
        self.tabSource.setObjectName(_fromUtf8("tabSource"))
        self.verticalLayoutSource = QtGui.QVBoxLayout(self.tabSource)
        self.verticalLayoutSource.setObjectName(_fromUtf8("verticalLayoutSource"))
        self.tabWidgetCode.addTab(self.tabSource, _fromUtf8(""))
        self.tabARMSim = QtGui.QWidget()
        self.tabARMSim.setAccessibleName(_fromUtf8(""))
        self.tabARMSim.setObjectName(_fromUtf8("tabARMSim"))
        self.verticalLayoutARMSim = QtGui.QVBoxLayout(self.tabARMSim)
        self.verticalLayoutARMSim.setObjectName(_fromUtf8("verticalLayoutARMSim"))
        self.tabWidgetCode.addTab(self.tabARMSim, _fromUtf8(""))
        self.verticalLayout.addWidget(self.tabWidgetCode)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 880, 21))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menuRun = QtGui.QMenu(self.menubar)
        self.menuRun.setObjectName(_fromUtf8("menuRun"))
        self.menuHelp = QtGui.QMenu(self.menubar)
        self.menuHelp.setObjectName(_fromUtf8("menuHelp"))
        self.menu_Window = QtGui.QMenu(self.menubar)
        self.menu_Window.setObjectName(_fromUtf8("menu_Window"))
        self.menu_Edit = QtGui.QMenu(self.menubar)
        self.menu_Edit.setObjectName(_fromUtf8("menu_Edit"))
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QtGui.QStatusBar(MainWindow)
        self.statusBar.setObjectName(_fromUtf8("statusBar"))
        MainWindow.setStatusBar(self.statusBar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.toolBar.sizePolicy().hasHeightForWidth())
        self.toolBar.setSizePolicy(sizePolicy)
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.dockWidgetRegisters = QtGui.QDockWidget(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidgetRegisters.sizePolicy().hasHeightForWidth())
        self.dockWidgetRegisters.setSizePolicy(sizePolicy)
        self.dockWidgetRegisters.setMinimumSize(QtCore.QSize(86, 108))
        self.dockWidgetRegisters.setToolTip(_fromUtf8(""))
        self.dockWidgetRegisters.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidgetRegisters.setObjectName(_fromUtf8("dockWidgetRegisters"))
        self.dockWidgetContentsRegisters = QtGui.QWidget()
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidgetContentsRegisters.sizePolicy().hasHeightForWidth())
        self.dockWidgetContentsRegisters.setSizePolicy(sizePolicy)
        self.dockWidgetContentsRegisters.setObjectName(_fromUtf8("dockWidgetContentsRegisters"))
        self.verticalLayout_6 = QtGui.QVBoxLayout(self.dockWidgetContentsRegisters)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.treeViewRegisters = MyQTreeView(self.dockWidgetContentsRegisters)
        self.treeViewRegisters.setEnabled(True)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier 10 Pitch"))
        self.treeViewRegisters.setFont(font)
        self.treeViewRegisters.setFrameShape(QtGui.QFrame.NoFrame)
        self.treeViewRegisters.setFrameShadow(QtGui.QFrame.Plain)
        self.treeViewRegisters.setLineWidth(0)
        self.treeViewRegisters.setAlternatingRowColors(True)
        self.treeViewRegisters.setObjectName(_fromUtf8("treeViewRegisters"))
        self.verticalLayout_6.addWidget(self.treeViewRegisters)
        self.dockWidgetRegisters.setWidget(self.dockWidgetContentsRegisters)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidgetRegisters)
        self.dockWidgetMemory = QtGui.QDockWidget(MainWindow)
        self.dockWidgetMemory.setMinimumSize(QtCore.QSize(180, 172))
        self.dockWidgetMemory.setToolTip(_fromUtf8(""))
        self.dockWidgetMemory.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidgetMemory.setObjectName(_fromUtf8("dockWidgetMemory"))
        self.dockWidgetContentsMemory = QtGui.QWidget()
        self.dockWidgetContentsMemory.setObjectName(_fromUtf8("dockWidgetContentsMemory"))
        self.dockWidgetMemoryLayout = QtGui.QVBoxLayout(self.dockWidgetContentsMemory)
        self.dockWidgetMemoryLayout.setObjectName(_fromUtf8("dockWidgetMemoryLayout"))
        self.treeViewMemory = MyQTreeView(self.dockWidgetContentsMemory)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier 10 Pitch"))
        self.treeViewMemory.setFont(font)
        self.treeViewMemory.setFrameShape(QtGui.QFrame.NoFrame)
        self.treeViewMemory.setFrameShadow(QtGui.QFrame.Plain)
        self.treeViewMemory.setLineWidth(0)
        self.treeViewMemory.setAlternatingRowColors(True)
        self.treeViewMemory.setObjectName(_fromUtf8("treeViewMemory"))
        self.dockWidgetMemoryLayout.addWidget(self.treeViewMemory)
        self.dockWidgetMemory.setWidget(self.dockWidgetContentsMemory)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidgetMemory)
        self.dockWidgetMessages = QtGui.QDockWidget(MainWindow)
        self.dockWidgetMessages.setAllowedAreas(QtCore.Qt.BottomDockWidgetArea)
        self.dockWidgetMessages.setObjectName(_fromUtf8("dockWidgetMessages"))
        self.dockWidgetMessagesContents = QtGui.QWidget()
        self.dockWidgetMessagesContents.setObjectName(_fromUtf8("dockWidgetMessagesContents"))
        self.verticalLayout_5 = QtGui.QVBoxLayout(self.dockWidgetMessagesContents)
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.textEditMessages = QtGui.QTextEdit(self.dockWidgetMessagesContents)
        self.textEditMessages.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textEditMessages.sizePolicy().hasHeightForWidth())
        self.textEditMessages.setSizePolicy(sizePolicy)
        self.textEditMessages.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.textEditMessages.setWhatsThis(_fromUtf8(""))
        self.textEditMessages.setDocumentTitle(_fromUtf8(""))
        self.textEditMessages.setTextInteractionFlags(QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.textEditMessages.setObjectName(_fromUtf8("textEditMessages"))
        self.verticalLayout_5.addWidget(self.textEditMessages)
        self.dockWidgetMessages.setWidget(self.dockWidgetMessagesContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(8), self.dockWidgetMessages)
        self.actionWhats_This = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/categories/system-help.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/categories/system-help.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/categories/system-help.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/categories/system-help.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/categories/system-help.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/categories/system-help.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("system-help"), myicon)
        # END section included by add_file_icons.py
        self.actionWhats_This.setIcon(icon)
        self.actionWhats_This.setObjectName(_fromUtf8("actionWhats_This"))
        self.actionAbout_Qt_ARMSim = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/help-about.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/help-about.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/help-about.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/help-about.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("help-about"), myicon)
        # END section included by add_file_icons.py
        self.actionAbout_Qt_ARMSim.setIcon(icon)
        self.actionAbout_Qt_ARMSim.setObjectName(_fromUtf8("actionAbout_Qt_ARMSim"))
        self.actionHelp = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/help-contents.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/help-contents.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/help-contents.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/help-contents.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("help-contents"), myicon)
        # END section included by add_file_icons.py
        self.actionHelp.setIcon(icon)
        self.actionHelp.setObjectName(_fromUtf8("actionHelp"))
        self.actionAbout_ARMSim = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/help-about.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/help-about.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/help-about.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/help-about.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("help-about"), myicon)
        # END section included by add_file_icons.py
        self.actionAbout_ARMSim.setIcon(icon)
        self.actionAbout_ARMSim.setObjectName(_fromUtf8("actionAbout_ARMSim"))
        self.actionNew = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-new.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-new.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-new.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-new.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-new"), myicon)
        # END section included by add_file_icons.py
        self.actionNew.setIcon(icon)
        self.actionNew.setObjectName(_fromUtf8("actionNew"))
        self.actionOpen = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-open.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-open.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-open.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-open.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-open"), myicon)
        # END section included by add_file_icons.py
        self.actionOpen.setIcon(icon)
        self.actionOpen.setObjectName(_fromUtf8("actionOpen"))
        self.actionSave = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-save.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-save.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-save.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-save.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-save"), myicon)
        # END section included by add_file_icons.py
        self.actionSave.setIcon(icon)
        self.actionSave.setObjectName(_fromUtf8("actionSave"))
        self.actionSave_As = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/document-save-as.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/document-save-as.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/document-save-as.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/document-save-as.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("document-save-as"), myicon)
        # END section included by add_file_icons.py
        self.actionSave_As.setIcon(icon)
        self.actionSave_As.setObjectName(_fromUtf8("actionSave_As"))
        self.actionQuit = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/actions/application-exit.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/actions/application-exit.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/actions/application-exit.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/application-exit.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/application-exit.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/application-exit.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("application-exit"), myicon)
        # END section included by add_file_icons.py
        self.actionQuit.setIcon(icon)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.actionReset_Registers = QtGui.QAction(MainWindow)
        self.actionReset_Registers.setObjectName(_fromUtf8("actionReset_Registers"))
        self.actionReset_Memory = QtGui.QAction(MainWindow)
        self.actionReset_Memory.setObjectName(_fromUtf8("actionReset_Memory"))
        self.actionClear_Console = QtGui.QAction(MainWindow)
        self.actionClear_Console.setObjectName(_fromUtf8("actionClear_Console"))
        self.actionRun = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/actions/system-run.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/actions/system-run.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/actions/system-run.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/system-run.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/system-run.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/system-run.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("system-run"), myicon)
        # END section included by add_file_icons.py
        self.actionRun.setIcon(icon)
        self.actionRun.setObjectName(_fromUtf8("actionRun"))
        self.actionStepInto = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/debug-step-into.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/debug-step-into.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/debug-step-into.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/debug-step-into.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("debug-step-into"), myicon)
        # END section included by add_file_icons.py
        self.actionStepInto.setIcon(icon)
        self.actionStepInto.setObjectName(_fromUtf8("actionStepInto"))
        self.actionBreakpoints = QtGui.QAction(MainWindow)
        self.actionBreakpoints.setObjectName(_fromUtf8("actionBreakpoints"))
        self.actionShow_Statusbar = QtGui.QAction(MainWindow)
        self.actionShow_Statusbar.setCheckable(True)
        self.actionShow_Statusbar.setChecked(True)
        self.actionShow_Statusbar.setObjectName(_fromUtf8("actionShow_Statusbar"))
        self.actionShow_Toolbar = QtGui.QAction(MainWindow)
        self.actionShow_Toolbar.setCheckable(True)
        self.actionShow_Toolbar.setChecked(True)
        self.actionShow_Toolbar.setObjectName(_fromUtf8("actionShow_Toolbar"))
        self.actionShow_Registers = QtGui.QAction(MainWindow)
        self.actionShow_Registers.setCheckable(True)
        self.actionShow_Registers.setChecked(True)
        self.actionShow_Registers.setObjectName(_fromUtf8("actionShow_Registers"))
        self.actionShow_Memory = QtGui.QAction(MainWindow)
        self.actionShow_Memory.setCheckable(True)
        self.actionShow_Memory.setChecked(True)
        self.actionShow_Memory.setObjectName(_fromUtf8("actionShow_Memory"))
        self.actionRestore_Default_Layout = QtGui.QAction(MainWindow)
        self.actionRestore_Default_Layout.setObjectName(_fromUtf8("actionRestore_Default_Layout"))
        self.actionPreferences = QtGui.QAction(MainWindow)
        self.actionPreferences.setObjectName(_fromUtf8("actionPreferences"))
        self.action_Undo = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-undo.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-undo.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-undo.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-undo.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-undo"), myicon)
        # END section included by add_file_icons.py
        self.action_Undo.setIcon(icon)
        self.action_Undo.setObjectName(_fromUtf8("action_Undo"))
        self.actionRedo = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-redo.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-redo.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-redo.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-redo.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-redo"), myicon)
        # END section included by add_file_icons.py
        self.actionRedo.setIcon(icon)
        self.actionRedo.setObjectName(_fromUtf8("actionRedo"))
        self.actionCut = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-cut.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-cut.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-cut.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-cut.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-cut"), myicon)
        # END section included by add_file_icons.py
        self.actionCut.setIcon(icon)
        self.actionCut.setObjectName(_fromUtf8("actionCut"))
        self.actionCopy = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-copy.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-copy.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-copy.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-copy.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-copy"), myicon)
        # END section included by add_file_icons.py
        self.actionCopy.setIcon(icon)
        self.actionCopy.setObjectName(_fromUtf8("actionCopy"))
        self.actionPaste = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/64x64/actions/edit-paste.png", QtCore.QSize(64, 64))
        myicon.addFile(":/themes/oxygen/128x128/actions/edit-paste.png", QtCore.QSize(128, 128))
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-paste.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-paste.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-paste.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-paste.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-paste"), myicon)
        # END section included by add_file_icons.py
        self.actionPaste.setIcon(icon)
        self.actionPaste.setObjectName(_fromUtf8("actionPaste"))
        self.actionSelect_All = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/edit-select-all.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/edit-select-all.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/edit-select-all.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/edit-select-all.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("edit-select-all"), myicon)
        # END section included by add_file_icons.py
        self.actionSelect_All.setIcon(icon)
        self.actionSelect_All.setObjectName(_fromUtf8("actionSelect_All"))
        self.actionShow_Messages = QtGui.QAction(MainWindow)
        self.actionShow_Messages.setCheckable(True)
        self.actionShow_Messages.setChecked(True)
        self.actionShow_Messages.setObjectName(_fromUtf8("actionShow_Messages"))
        self.actionStepOver = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/debug-step-over.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/debug-step-over.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/debug-step-over.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/debug-step-over.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("debug-step-over"), myicon)
        # END section included by add_file_icons.py
        self.actionStepOver.setIcon(icon)
        self.actionStepOver.setObjectName(_fromUtf8("actionStepOver"))
        self.actionRestart = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/view-refresh.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/view-refresh.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/view-refresh.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/view-refresh.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("view-refresh"), myicon)
        # END section included by add_file_icons.py
        self.actionRestart.setIcon(icon)
        self.actionRestart.setObjectName(_fromUtf8("actionRestart"))
        self.actionResume = QtGui.QAction(MainWindow)
        # BEGIN section included by add_file_icons.py
        myicon = QtGui.QIcon()
        myicon.addFile(":/themes/oxygen/32x32/actions/debug-run.png", QtCore.QSize(32, 32))
        myicon.addFile(":/themes/oxygen/22x22/actions/debug-run.png", QtCore.QSize(22, 22))
        myicon.addFile(":/themes/oxygen/48x48/actions/debug-run.png", QtCore.QSize(48, 48))
        myicon.addFile(":/themes/oxygen/16x16/actions/debug-run.png", QtCore.QSize(16, 16))
        icon = QtGui.QIcon.fromTheme(_fromUtf8("debug-run"), myicon)
        # END section included by add_file_icons.py
        self.actionResume.setIcon(icon)
        self.actionResume.setObjectName(_fromUtf8("actionResume"))
        self.menuFile.addAction(self.actionNew)
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSave)
        self.menuFile.addAction(self.actionSave_As)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuRun.addAction(self.actionRun)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionStepInto)
        self.menuRun.addAction(self.actionStepOver)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionRestart)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionBreakpoints)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionReset_Registers)
        self.menuRun.addAction(self.actionReset_Memory)
        self.menuRun.addAction(self.actionClear_Console)
        self.menuHelp.addAction(self.actionHelp)
        self.menuHelp.addAction(self.actionWhats_This)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_Qt_ARMSim)
        self.menuHelp.addAction(self.actionAbout_ARMSim)
        self.menu_Window.addAction(self.actionShow_Statusbar)
        self.menu_Window.addAction(self.actionShow_Toolbar)
        self.menu_Window.addAction(self.actionShow_Registers)
        self.menu_Window.addAction(self.actionShow_Memory)
        self.menu_Window.addAction(self.actionShow_Messages)
        self.menu_Window.addSeparator()
        self.menu_Window.addAction(self.actionRestore_Default_Layout)
        self.menu_Window.addSeparator()
        self.menu_Edit.addAction(self.action_Undo)
        self.menu_Edit.addAction(self.actionRedo)
        self.menu_Edit.addSeparator()
        self.menu_Edit.addAction(self.actionCut)
        self.menu_Edit.addAction(self.actionCopy)
        self.menu_Edit.addAction(self.actionPaste)
        self.menu_Edit.addSeparator()
        self.menu_Edit.addAction(self.actionSelect_All)
        self.menu_Edit.addSeparator()
        self.menu_Edit.addAction(self.actionPreferences)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menu_Edit.menuAction())
        self.menubar.addAction(self.menu_Window.menuAction())
        self.menubar.addAction(self.menuRun.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionOpen)
        self.toolBar.addAction(self.actionSave)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_Undo)
        self.toolBar.addAction(self.actionRedo)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionRun)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionStepInto)
        self.toolBar.addAction(self.actionStepOver)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionRestart)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionWhats_This)

        self.retranslateUi(MainWindow)
        self.tabWidgetCode.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        self.tabSource.setWhatsThis(_translate("MainWindow", "The Source Code tab is used to edit the assembler source code that is going to be simmulated", None))
        self.tabWidgetCode.setTabText(self.tabWidgetCode.indexOf(self.tabSource), _translate("MainWindow", "Source Code", None))
        self.tabARMSim.setWhatsThis(_translate("MainWindow", "The ArmSim tab is used to inspect and simmulate the ARM machine code generated after assembling the source code", None))
        self.tabWidgetCode.setTabText(self.tabWidgetCode.indexOf(self.tabARMSim), _translate("MainWindow", "ARMSim", None))
        self.menuFile.setTitle(_translate("MainWindow", "&File", None))
        self.menuRun.setTitle(_translate("MainWindow", "&Run", None))
        self.menuHelp.setTitle(_translate("MainWindow", "Help", None))
        self.menu_Window.setTitle(_translate("MainWindow", "&View", None))
        self.menu_Edit.setTitle(_translate("MainWindow", "&Edit", None))
        self.toolBar.setWindowTitle(_translate("MainWindow", "Barra de herramientas", None))
        self.dockWidgetRegisters.setWhatsThis(_translate("MainWindow", "The Registers dock shows the contents of the registers", None))
        self.dockWidgetRegisters.setWindowTitle(_translate("MainWindow", "Registers", None))
        self.dockWidgetMemory.setWhatsThis(_translate("MainWindow", "The Memory dock shows the contents of the memory", None))
        self.dockWidgetMemory.setWindowTitle(_translate("MainWindow", "Memory", None))
        self.dockWidgetMessages.setWhatsThis(_translate("MainWindow", "The Messages dock shows Qt ARMSim and ARMSim messages", None))
        self.dockWidgetMessages.setWindowTitle(_translate("MainWindow", "Messages", None))
        self.actionWhats_This.setText(_translate("MainWindow", "What\'s &This?", None))
        self.actionWhats_This.setStatusTip(_translate("MainWindow", "¿Qué es esto?", None))
        self.actionWhats_This.setWhatsThis(_translate("MainWindow", "Activa la ayuda", None))
        self.actionWhats_This.setShortcut(_translate("MainWindow", "Shift+F1", None))
        self.actionAbout_Qt_ARMSim.setText(_translate("MainWindow", "About Qt ARMSim", None))
        self.actionAbout_Qt_ARMSim.setStatusTip(_translate("MainWindow", "Sobre spim", None))
        self.actionAbout_Qt_ARMSim.setWhatsThis(_translate("MainWindow", "Imprime en el panel mensajes información sobre XSPIM", None))
        self.actionHelp.setText(_translate("MainWindow", "Qt ArmSim &Help", None))
        self.actionHelp.setShortcut(_translate("MainWindow", "F1", None))
        self.actionAbout_ARMSim.setText(_translate("MainWindow", "About ARMSim", None))
        self.actionNew.setText(_translate("MainWindow", "&New...", None))
        self.actionNew.setShortcut(_translate("MainWindow", "Ctrl+N", None))
        self.actionOpen.setText(_translate("MainWindow", "&Open...", None))
        self.actionOpen.setToolTip(_translate("MainWindow", "Open ARM assembler file", None))
        self.actionOpen.setShortcut(_translate("MainWindow", "Ctrl+O", None))
        self.actionSave.setText(_translate("MainWindow", "&Save", None))
        self.actionSave.setShortcut(_translate("MainWindow", "Ctrl+S", None))
        self.actionSave_As.setText(_translate("MainWindow", "Save &As...", None))
        self.actionQuit.setText(_translate("MainWindow", "&Quit", None))
        self.actionQuit.setShortcut(_translate("MainWindow", "Ctrl+Q", None))
        self.actionReset_Registers.setText(_translate("MainWindow", "Reset R&egisters", None))
        self.actionReset_Memory.setText(_translate("MainWindow", "Reset &Memory", None))
        self.actionClear_Console.setText(_translate("MainWindow", "Clear &Console", None))
        self.actionRun.setText(_translate("MainWindow", "&Run", None))
        self.actionRun.setShortcut(_translate("MainWindow", "Ctrl+F11", None))
        self.actionStepInto.setText(_translate("MainWindow", "Step &Into", None))
        self.actionStepInto.setToolTip(_translate("MainWindow", "Step Into", None))
        self.actionStepInto.setShortcut(_translate("MainWindow", "F5", None))
        self.actionBreakpoints.setText(_translate("MainWindow", "&Breakpoints", None))
        self.actionBreakpoints.setShortcut(_translate("MainWindow", "Ctrl+B", None))
        self.actionShow_Statusbar.setText(_translate("MainWindow", "Show St&atusbar", None))
        self.actionShow_Toolbar.setText(_translate("MainWindow", "Show &Toolbar", None))
        self.actionShow_Registers.setText(_translate("MainWindow", "Show &Registers", None))
        self.actionShow_Memory.setText(_translate("MainWindow", "Show &Memory", None))
        self.actionRestore_Default_Layout.setText(_translate("MainWindow", "Restore Default &Layout", None))
        self.actionRestore_Default_Layout.setShortcut(_translate("MainWindow", "F3", None))
        self.actionPreferences.setText(_translate("MainWindow", "&Preferences...", None))
        self.action_Undo.setText(_translate("MainWindow", "&Undo", None))
        self.action_Undo.setShortcut(_translate("MainWindow", "Ctrl+Z", None))
        self.actionRedo.setText(_translate("MainWindow", "Re&do", None))
        self.actionRedo.setShortcut(_translate("MainWindow", "Ctrl+Shift+Z", None))
        self.actionCut.setText(_translate("MainWindow", "Cu&t", None))
        self.actionCut.setShortcut(_translate("MainWindow", "Ctrl+X", None))
        self.actionCopy.setText(_translate("MainWindow", "&Copy", None))
        self.actionCopy.setShortcut(_translate("MainWindow", "Ctrl+C", None))
        self.actionPaste.setText(_translate("MainWindow", "&Paste", None))
        self.actionPaste.setShortcut(_translate("MainWindow", "Ctrl+V", None))
        self.actionSelect_All.setText(_translate("MainWindow", "Select &All", None))
        self.actionSelect_All.setShortcut(_translate("MainWindow", "Ctrl+A", None))
        self.actionShow_Messages.setText(_translate("MainWindow", "Show M&essages", None))
        self.actionStepOver.setText(_translate("MainWindow", "Step &Over", None))
        self.actionStepOver.setToolTip(_translate("MainWindow", "Step Over", None))
        self.actionStepOver.setShortcut(_translate("MainWindow", "F6", None))
        self.actionRestart.setText(_translate("MainWindow", "Re&start", None))
        self.actionRestart.setToolTip(_translate("MainWindow", "Restart Simulation", None))
        self.actionRestart.setShortcut(_translate("MainWindow", "F4", None))
        self.actionResume.setText(_translate("MainWindow", "Resu&me", None))
        self.actionResume.setToolTip(_translate("MainWindow", "Resume Execution", None))
        self.actionResume.setShortcut(_translate("MainWindow", "F8", None))

from ..widget.myqtreeview import MyQTreeView
from ..res import oxygen_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/ejec.ui'
#
# Created: Tue Sep  2 17:00:03 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Ejecutar(object):
    def setupUi(self, Ejecutar):
        Ejecutar.setObjectName(_fromUtf8("Ejecutar"))
        Ejecutar.resize(400, 172)
        self.adress = QtGui.QLineEdit(Ejecutar)
        self.adress.setGeometry(QtCore.QRect(20, 50, 113, 20))
        self.adress.setToolTip(_fromUtf8(""))
        self.adress.setInputMask(_fromUtf8(""))
        self.adress.setObjectName(_fromUtf8("adress"))
        self.adresslabel = QtGui.QLabel(Ejecutar)
        self.adresslabel.setGeometry(QtCore.QRect(20, 20, 88, 31))
        self.adresslabel.setObjectName(_fromUtf8("adresslabel"))
        self.linelabel = QtGui.QLabel(Ejecutar)
        self.linelabel.setGeometry(QtCore.QRect(20, 80, 98, 16))
        self.linelabel.setObjectName(_fromUtf8("linelabel"))
        self.lineEdit = QtGui.QLineEdit(Ejecutar)
        self.lineEdit.setGeometry(QtCore.QRect(20, 100, 113, 20))
        self.lineEdit.setObjectName(_fromUtf8("lineEdit"))
        self.undefcheckBox = QtGui.QCheckBox(Ejecutar)
        self.undefcheckBox.setGeometry(QtCore.QRect(20, 130, 161, 18))
        self.undefcheckBox.setObjectName(_fromUtf8("undefcheckBox"))
        self.aceptarButton = QtGui.QPushButton(Ejecutar)
        self.aceptarButton.setGeometry(QtCore.QRect(280, 40, 75, 23))
        self.aceptarButton.setObjectName(_fromUtf8("aceptarButton"))
        self.cancelarButton = QtGui.QPushButton(Ejecutar)
        self.cancelarButton.setGeometry(QtCore.QRect(280, 90, 75, 23))
        self.cancelarButton.setObjectName(_fromUtf8("cancelarButton"))

        self.retranslateUi(Ejecutar)
        QtCore.QMetaObject.connectSlotsByName(Ejecutar)

    def retranslateUi(self, Ejecutar):
        Ejecutar.setWindowTitle(_translate("Ejecutar", "Parámatros de ejecución", None))
        self.adress.setText(_translate("Ejecutar", "0x00000000", None))
        self.adresslabel.setText(_translate("Ejecutar", "Dirección de inicio:", None))
        self.linelabel.setText(_translate("Ejecutar", "Línea de instrucción:", None))
        self.undefcheckBox.setText(_translate("Ejecutar", "Buscar símbolos no definidos", None))
        self.aceptarButton.setText(_translate("Ejecutar", "Aceptar", None))
        self.cancelarButton.setText(_translate("Ejecutar", "Cancelar", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

###########################################################################
#                                                                         #
#  This file is part of Qt ARMSim.                                        #
#                                                                         #
#  Qt ARMSim is free software: you can redistribute it and/or modify      #
#  it under the terms of the GNU General Public License as published by   #
#  the Free Software Foundation; either version 3 of the License, or      #
#  (at your option) any later version.                                    #
#                                                                         #
#  This program is distributed in the hope that it will be useful, but    #
#  WITHOUT ANY WARRANTY; without even the implied warranty of             #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      #
#  General Public License for more details.                               #
#                                                                         #
###########################################################################

#===============================================================================
# References:
#  uni-projekt / debugger / asmeditor.py
#  https://github.com/svenstaro/uni-projekt/blob/master/debugger/asmeditor.py
#===============================================================================

import re

from PyQt4.Qsci import QsciLexerCustom
from PyQt4.QtGui import QColor


class QsciLexerARM(QsciLexerCustom):

    def __init__(self, parent):
        super(QsciLexerARM, self).__init__(parent)
        self._styles = {
            0: 'Default',
            1: 'Comment',
            2: 'Instruction',
            3: 'Register',
            4: 'Immediate',
            5: 'Label',
            6: 'Data',
            7: 'Directive',
        }
        for key, value in self._styles.items():
            setattr(self, value, key)

    def language(self):
        return "ARM Assembler"

    def description(self, style):
        return self._styles.get(style, '')

    def defaultColor(self, style):
        if style == self.Default:
            return QColor('#000000')
        elif style == self.Comment:
            return QColor('#898887')
        elif style == self.Instruction:
            return QColor('#000000')
        elif style == self.Register:
            return QColor('#00C0C0')
        elif style == self.Immediate:
            return QColor('#00CC00')
        elif style == self.Label:
            return QColor('#006E28')
        elif style == self.Data:
            return QColor('#FEDCBA')
        elif style == self.Directive:
            return QColor('#FF8000')
        return super(QsciLexerARM, self).defaultColor(style)

    def defaultFont(self, style):
        font = super(QsciLexerARM, self).defaultFont(style)
        if style == self.Instruction:
            font.setBold(True)
        return font

    def defaultPaper(self, style):
        return QColor('#FFFFFF')

        
    def styleText(self, start, end):
        editor = self.editor()
        if editor is None:
            return

        # scintilla works with encoded bytes, not decoded characters.
        # this matters if the source contains non-ascii characters and
        # a multi-byte encoding is used (e.g. utf-8)
        source = ''
        if end >= editor.length():
            end = editor.length()-1
        if end > start:
            source = bytearray(end - start)
            editor.SendScintilla(editor.SCI_GETTEXTRANGE, start, end, source)
        if not source:
            return

        self.startStyling(start, 0x1f)

        for line in source.splitlines(False):
            length = len(line)
            
            # Search the beginning of a comment
            comment_marks=(b';', b'@', b'#if', b'#else', b'#end')
            try:
                commentStart = min([line.find(c) for c in comment_marks if line.find(c)!=-1])
            except ValueError:
                commentStart = -1
            
            # Process now the part of the line that is before the comment mark
            cmd = line if commentStart == -1 else line[:commentStart]

            # If there is part of the line unprocessed, check first if there is a label on it
            if cmd != '':
                # If there is a ':', then the first part of the line is marked as a label
                pos = cmd.find(b':')
                if pos != -1:
                    self.setStyling(pos+1, self.Label)
                    cmd = cmd[pos+1:]
            
            # If there is still a part of the line unprocessed, then process it
            firstWord = True
            while cmd != b'':
                searchWord = re.search(b'([^ ,]+)', cmd)
                if searchWord != None:
                    word = searchWord.groups()[0]
                    style = self.Default
                    if word.startswith(b'.'):
                        style = self.Directive
                        firstWord = False
                    elif firstWord:
                        style = self.Instruction
                        firstWord = False
                    elif word.startswith(b'r'):
                        style = self.Register
                    elif word.startswith(b'#'):
                        style = self.Immediate
                    startpos = searchWord.start()
                    endpos = searchWord.end()
                    if startpos != 0:
                        self.setStyling(startpos, self.Default)
                    self.setStyling(endpos-startpos, style)
                    cmd = cmd[endpos:]
                else:
                    # Consume the cmd string
                    self.setStyling(len(cmd), self.Default)
                    cmd = b''
                
            # Finally, set the style of the comment
            if commentStart != -1:
                self.setStyling(length - commentStart, self.Comment)

            # And the style of the newline character
            self.setStyling(1, self.Default)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/breakpo.ui'
#
# Created: Tue Sep  2 17:00:03 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Break(object):
    def setupUi(self, Break):
        Break.setObjectName(_fromUtf8("Break"))
        Break.resize(400, 300)

        self.retranslateUi(Break)
        QtCore.QMetaObject.connectSlotsByName(Break)

    def retranslateUi(self, Break):
        Break.setWindowTitle(_translate("Break", "Puntos de ruptura", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/opciones.ui'
#
# Created: Tue Sep  2 17:00:04 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Opciones(object):
    def setupUi(self, Opciones):
        Opciones.setObjectName(_fromUtf8("Opciones"))
        Opciones.resize(400, 300)
        self.actionExplorar = QtGui.QPushButton(Opciones)
        self.actionExplorar.setGeometry(QtCore.QRect(280, 130, 75, 23))
        self.actionExplorar.setObjectName(_fromUtf8("actionExplorar"))
        self.Bare = QtGui.QCheckBox(Opciones)
        self.Bare.setGeometry(QtCore.QRect(41, 51, 99, 18))
        self.Bare.setObjectName(_fromUtf8("Bare"))
        self.Quiet = QtGui.QCheckBox(Opciones)
        self.Quiet.setGeometry(QtCore.QRect(146, 51, 99, 18))
        self.Quiet.setObjectName(_fromUtf8("Quiet"))
        self.Mapped = QtGui.QCheckBox(Opciones)
        self.Mapped.setGeometry(QtCore.QRect(251, 51, 99, 18))
        self.Mapped.setObjectName(_fromUtf8("Mapped"))
        self.Loadtrap = QtGui.QCheckBox(Opciones)
        self.Loadtrap.setGeometry(QtCore.QRect(41, 136, 87, 18))
        self.Loadtrap.setObjectName(_fromUtf8("Loadtrap"))
        self.Directrap = QtGui.QLineEdit(Opciones)
        self.Directrap.setGeometry(QtCore.QRect(134, 135, 133, 20))
        self.Directrap.setObjectName(_fromUtf8("Directrap"))
        self.cancelarButton = QtGui.QPushButton(Opciones)
        self.cancelarButton.setGeometry(QtCore.QRect(290, 240, 75, 23))
        self.cancelarButton.setObjectName(_fromUtf8("cancelarButton"))
        self.buttonBox = QtGui.QPushButton(Opciones)
        self.buttonBox.setGeometry(QtCore.QRect(190, 240, 75, 23))
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))

        self.retranslateUi(Opciones)
        QtCore.QMetaObject.connectSlotsByName(Opciones)

    def retranslateUi(self, Opciones):
        Opciones.setWindowTitle(_translate("Opciones", "Opciones", None))
        self.actionExplorar.setText(_translate("Opciones", "Explorar", None))
        self.Bare.setText(_translate("Opciones", "Bare mode", None))
        self.Quiet.setText(_translate("Opciones", "Quiet mode", None))
        self.Mapped.setText(_translate("Opciones", "Mapped I/O", None))
        self.Loadtrap.setText(_translate("Opciones", "Load trap file", None))
        self.cancelarButton.setText(_translate("Opciones", "Cancelar", None))
        self.buttonBox.setText(_translate("Opciones", "Aceptar", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/value.ui'
#
# Created: Tue Sep  2 17:00:03 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Value(object):
    def setupUi(self, Value):
        Value.setObjectName(_fromUtf8("Value"))
        Value.resize(400, 142)
        self.direcLabel = QtGui.QLabel(Value)
        self.direcLabel.setGeometry(QtCore.QRect(20, 20, 151, 16))
        self.direcLabel.setObjectName(_fromUtf8("direcLabel"))
        self.direcLineEdit = QtGui.QLineEdit(Value)
        self.direcLineEdit.setGeometry(QtCore.QRect(20, 40, 201, 20))
        self.direcLineEdit.setObjectName(_fromUtf8("direcLineEdit"))
        self.valueLabel = QtGui.QLabel(Value)
        self.valueLabel.setGeometry(QtCore.QRect(20, 80, 46, 14))
        self.valueLabel.setObjectName(_fromUtf8("valueLabel"))
        self.valueLineEdit = QtGui.QLineEdit(Value)
        self.valueLineEdit.setGeometry(QtCore.QRect(20, 100, 201, 20))
        self.valueLineEdit.setObjectName(_fromUtf8("valueLineEdit"))
        self.aceptarButton = QtGui.QPushButton(Value)
        self.aceptarButton.setGeometry(QtCore.QRect(290, 20, 75, 23))
        self.aceptarButton.setObjectName(_fromUtf8("aceptarButton"))
        self.cancelarButton = QtGui.QPushButton(Value)
        self.cancelarButton.setGeometry(QtCore.QRect(290, 60, 75, 23))
        self.cancelarButton.setObjectName(_fromUtf8("cancelarButton"))

        self.retranslateUi(Value)
        QtCore.QMetaObject.connectSlotsByName(Value)

    def retranslateUi(self, Value):
        Value.setWindowTitle(_translate("Value", "Asignar valor a registro", None))
        self.direcLabel.setText(_translate("Value", "Dirección o nombre de registro:", None))
        self.valueLabel.setText(_translate("Value", "Valor:", None))
        self.aceptarButton.setText(_translate("Value", "Aceptar", None))
        self.cancelarButton.setText(_translate("Value", "Cancelar", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/help.ui'
#
# Created: Tue Sep  2 17:00:03 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Help(object):
    def setupUi(self, Help):
        Help.setObjectName(_fromUtf8("Help"))
        Help.resize(562, 524)

        self.retranslateUi(Help)
        QtCore.QMetaObject.connectSlotsByName(Help)

    def retranslateUi(self, Help):
        Help.setWindowTitle(_translate("Help", "Help", None))

from ..res import oxygen_rc



# -*- coding: utf-8 -*-

#===============================================================================
# References:
#   Sample using QScintilla with PyQt
#   http://eli.thegreenplace.net/2011/04/01/sample-using-qscintilla-with-pyqt/
#===============================================================================

import sys

from PyQt4 import QtCore, QtGui
from PyQt4.Qsci import QsciScintilla

from .qscilexerarm import QsciLexerARM


class SimpleARMEditor(QsciScintilla):

    # breakpoint_changed signal, parameters are if set or unset (True/False) and hex_address
    breakpoint_changed = QtCore.pyqtSignal(int, 'QString')

    # Markers
    BREAKPOINT_MARKER = QsciScintilla.Circle
    PC_MARKER1 = QsciScintilla.RightArrow
    PC_MARKER2 = QsciScintilla.Background
    
    def __init__(self, parent=None, disassemble=False):
        super(SimpleARMEditor, self).__init__(parent)

        # Set the default font
        font = QtGui.QFont()
        font.setFamily('Courier')
        font.setFixedPitch(True)
        font.setPointSize(10)
        self.setFont(font)
        self.setMarginsFont(font)
        self.setMarginsBackgroundColor(QtGui.QColor("#CCCCCC"))

        # Marker related variables
        self.breakpoints = {}
        self.last_highlighted_line = 0

        if disassemble:
            self.setReadOnly(True)
            # No cursor
            self.setCaretWidth(0)
            # Brace matching kind
            self.setBraceMatching(QsciScintilla.NoBraceMatch)
            # Margin on disassembler
            self.setMarginType(1, QsciScintilla.SymbolMargin)
            self.setMarginSensitivity(1, True)
            # Clickable margin configuration
            self.connect(self, QtCore.SIGNAL('marginClicked(int, int, Qt::KeyboardModifiers)'), self.on_margin_clicked)
            # Breakpoint marker (white circle filled with red)
            self.markerDefine(self.BREAKPOINT_MARKER, self.BREAKPOINT_MARKER)
            self.setMarkerForegroundColor(QtGui.QColor("#DDDDDD"), self.BREAKPOINT_MARKER)
            self.setMarkerBackgroundColor(QtGui.QColor("#DD5555"), self.BREAKPOINT_MARKER)
            # PC Marker 1 (white right arrow filled with light blue)
            self.markerDefine(self.PC_MARKER1, self.PC_MARKER1)
            self.setMarkerForegroundColor(QtGui.QColor("#000000"), self.PC_MARKER1)
            self.setMarkerBackgroundColor(QtGui.QColor("#E4E4FF"), self.PC_MARKER1)
            # PC Marker 2 (line background with light blue)
            self.markerDefine(self.PC_MARKER2, self.PC_MARKER2)
            self.setMarkerForegroundColor(QtGui.QColor("#FFFFFF"), self.PC_MARKER2) # Not used
            self.setMarkerBackgroundColor(QtGui.QColor("#E4E4FF"), self.PC_MARKER2)
        else:
            # Brace matching kind
            self.setBraceMatching(QsciScintilla.SloppyBraceMatch)
            # Margin on editor
            self.setMarginType(0, QsciScintilla.NumberMargin)
            self.setMarginWidth(0, QtGui.QFontMetrics(font).width("0000") + 6)
            self.setMarginWidth(1, 0)
            # Current line visible with special background color
            self.setCaretLineVisible(True)
            self.setCaretLineBackgroundColor(QtGui.QColor("#e4e4ff"))
            # Don't want to see the horizontal scrollbar at all
            self.SendScintilla(QsciScintilla.SCI_SETHSCROLLBAR, 0)
        
        # Set encoding as UTF-8
        self.setUtf8(True)

        # Set lexer
        lexer = QsciLexerARM(self)
        lexer.setDefaultFont(font)
        self.setLexer(lexer)

        # Not too small
        # self.setMinimumSize(400, 300)

    def on_margin_clicked(self, nmargin, nline, modifiers):
        # Get hex address from nline
        hex_address = self.text(nline).split(" ")[0][1:-1]
        # Toggle marker for the line the margin was clicked on
        if self.breakpoints.get(nline):
            self.markerDelete(nline, self.BREAKPOINT_MARKER)
            self.breakpoints.pop(nline)
            self.breakpoint_changed.emit(False, hex_address)
        else:
            self.markerAdd(nline, self.BREAKPOINT_MARKER)
            self.breakpoints[nline] = True
            self.breakpoint_changed.emit(True, hex_address)

    def highlightPCLine(self, nline):
        #self.setFocus()
        self.setCursorPosition(nline, 0)
        self.ensureLineVisible(nline)
        self.markerDelete(self.last_highlighted_line, self.PC_MARKER1)
        self.markerDelete(self.last_highlighted_line, self.PC_MARKER2)
        self.markerAdd(nline, self.PC_MARKER1)
        self.markerAdd(nline, self.PC_MARKER2)
        self.last_highlighted_line = nline

    def setText(self, text):
        super(SimpleARMEditor, self).setText(text)
        # Restore breakpoints
        for nline in self.breakpoints.keys():
            self.markerAdd(nline, self.BREAKPOINT_MARKER)

    def clearBreakpoints(self):
        for nline in self.breakpoints.keys():
            self.markerDelete(nline, self.BREAKPOINT_MARKER)
        self.breakpoints.clear()

if __name__ == "__main__":
    app = QtGui.QApplication(sys.argv)
    editor = SimpleARMEditor()
    editor.show()
    editor.setText(open("hello_world.asm").read())
    app.exec_()



# Use the following command to create a source distribution and upload it to the
# testpypi repository:
#
# python3 ./setup.py sdist upload -r testpypi
#

from setuptools import setup, find_packages  # Always prefer setuptools over distutils

from settings import Settings

# Common settings to setuptools and cx_freeze
s = Settings()

# Setup
setup(
        # Application details
        name = s.name,
        version = s.version,
        description = s.description,
        url = s.url,
        # Author details
        author = s.author,
        author_email = s.email,
        # License
        license = s.license,
        # Application classifiers
        classifiers = s.classifiers,
        # Application keywords
        keywords = s.keywords,
    
        # --------------------------------
        #  setuptools parameters
        # --------------------------------
        packages = find_packages(exclude=['build', 'dist', 'distfiles', 'docs', 'examples', 'scripts', 'tmp']),
        package_data = s.package_data,
        entry_points={
            'gui_scripts': [
                'qtarmsim=qtarmsim:main',
            ],
        },
      )



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtarmsim/ui/imprimir.ui'
#
# Created: Tue Sep  2 17:00:02 2014
#      by: PyQt4 UI code generator 4.10.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Imprimir(object):
    def setupUi(self, Imprimir):
        Imprimir.setObjectName(_fromUtf8("Imprimir"))
        Imprimir.resize(400, 300)
        self.aceptarButton = QtGui.QPushButton(Imprimir)
        self.aceptarButton.setGeometry(QtCore.QRect(300, 30, 75, 23))
        self.aceptarButton.setObjectName(_fromUtf8("aceptarButton"))
        self.cancelarButton = QtGui.QPushButton(Imprimir)
        self.cancelarButton.setGeometry(QtCore.QRect(300, 70, 75, 23))
        self.cancelarButton.setObjectName(_fromUtf8("cancelarButton"))
        self.comboBox = QtGui.QComboBox(Imprimir)
        self.comboBox.setGeometry(QtCore.QRect(30, 40, 181, 21))
        self.comboBox.setObjectName(_fromUtf8("comboBox"))
        self.labelFrom = QtGui.QLabel(Imprimir)
        self.labelFrom.setGeometry(QtCore.QRect(30, 110, 46, 14))
        self.labelFrom.setObjectName(_fromUtf8("labelFrom"))
        self.Tolabel = QtGui.QLabel(Imprimir)
        self.Tolabel.setGeometry(QtCore.QRect(30, 170, 46, 14))
        self.Tolabel.setObjectName(_fromUtf8("Tolabel"))
        self.fromEdit = QtGui.QLineEdit(Imprimir)
        self.fromEdit.setEnabled(False)
        self.fromEdit.setGeometry(QtCore.QRect(30, 130, 121, 20))
        self.fromEdit.setObjectName(_fromUtf8("fromEdit"))
        self.toEdit = QtGui.QLineEdit(Imprimir)
        self.toEdit.setEnabled(False)
        self.toEdit.setGeometry(QtCore.QRect(30, 190, 121, 20))
        self.toEdit.setObjectName(_fromUtf8("toEdit"))

        self.retranslateUi(Imprimir)
        QtCore.QMetaObject.connectSlotsByName(Imprimir)

    def retranslateUi(self, Imprimir):
        Imprimir.setWindowTitle(_translate("Imprimir", "Imprimir valor", None))
        self.aceptarButton.setText(_translate("Imprimir", "Aceptar", None))
        self.cancelarButton.setText(_translate("Imprimir", "Cancelar", None))
        self.labelFrom.setText(_translate("Imprimir", "From:", None))
        self.Tolabel.setText(_translate("Imprimir", "to:", None))

from ..res import oxygen_rc
